# dolfin_mech
A set of FEniCS-based python tools for Computational Mechanics.
### Requirements
You need a working installation of FEniCS (including DOLFIN python interface).
### Installation
```
pip install dolfin_mech
```
